@@ -72,9 +72,9 @@ main (int argc, char **argv)
   const char *home_dir;
   GError *error = NULL;
 
-  if (G_UNLIKELY (getuid () != geteuid () ||
-                  getgid () != getegid () ||
-                  geteuid () == 0 || 
+  if (G_UNLIKELY ((getuid () != geteuid () ||
+                  getgid () != getegid ()) &&
+                  geteuid () == 0 &&
                   getegid () == 0)) {
     g_printerr ("Wrong euid/egid, exiting.\n");
     return EXIT_FAILURE;
